import json
import os

from ..settings import DEFAULT_CREDENTIALS_FILE_NAME
from ..exceptions import (
    CredentialsFileMissingException,
    CredentialsNotFoundException
)


def get_credentials(
    url,
    credentials_file_name=DEFAULT_CREDENTIALS_FILE_NAME
):
    path = os.path.join(os.path.expanduser("~"), credentials_file_name)
    if not os.path.isfile(path):
        raise CredentialsFileMissingException(
            "There is no credentials file found."
        )
    with open(path, encoding="utf-8") as f:
        data = json.loads(f.read())
        if url not in data:
            raise CredentialsNotFoundException(
                "There are no credentials for that url."
            )
        credentials = data[url]
        return credentials

